#########
Component
#########

.. |br| raw:: html

   <br />

.. automodule:: aristopy.component

.. toctree::
   :maxdepth: 1

   sourceSink
   conversion
   bus
   storage

.. autoclass:: Component
   :members:
..   :undoc-members: